import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { ProjectGcjlVO, ProjectGcjlForm, ProjectGcjlQuery } from '@/api/project/projectGcjl/types';

/**
 * 查询造价咨询列表
 * @param query
 * @returns {*}
 */

export const listProjectGcjl = (query?: ProjectGcjlQuery): AxiosPromise<ProjectGcjlVO[]> => {
  return request({
    url: '/project/projectGcjl/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询造价咨询详细
 * @param id
 */
export const getProjectGcjl = (id: string | number): AxiosPromise<ProjectGcjlVO> => {
  return request({
    url: '/project/projectGcjl/' + id,
    method: 'get'
  });
};

/**
 * 新增造价咨询
 * @param data
 */
export const addProjectGcjl = (data: ProjectGcjlForm) => {
  return request({
    url: '/project/projectGcjl',
    method: 'post',
    data: data
  });
};

/**
 * 修改造价咨询
 * @param data
 */
export const updateProjectGcjl = (data: ProjectGcjlForm) => {
  return request({
    url: '/project/projectGcjl',
    method: 'put',
    data: data
  });
};

/**
 * 删除造价咨询
 * @param id
 */
export const delProjectGcjl = (id: string | number | Array<string | number>) => {
  return request({
    url: '/project/projectGcjl/' + id,
    method: 'delete'
  });
};
