import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { ProjectJsxmVO, ProjectJsxmForm, ProjectJsxmQuery } from '@/api/project/projectJsxm/types';

/**
 * 查询建设项目列表
 * @param query
 * @returns {*}
 */

export const listProjectJsxm = (query?: ProjectJsxmQuery): AxiosPromise<ProjectJsxmVO[]> => {
  return request({
    url: '/project/projectJsxm/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询建设项目详细
 * @param id
 */
export const getProjectJsxm = (id: string | number): AxiosPromise<ProjectJsxmVO> => {
  return request({
    url: '/project/projectJsxm/' + id,
    method: 'get'
  });
};

/**
 * 新增建设项目
 * @param data
 */
export const addProjectJsxm = (data: ProjectJsxmForm) => {
  return request({
    url: '/project/projectJsxm',
    method: 'post',
    data: data
  });
};

/**
 * 修改建设项目
 * @param data
 */
export const updateProjectJsxm = (data: ProjectJsxmForm) => {
  return request({
    url: '/project/projectJsxm',
    method: 'put',
    data: data
  });
};

/**
 * 删除建设项目
 * @param id
 */
export const delProjectJsxm = (id: string | number | Array<string | number>) => {
  return request({
    url: '/project/projectJsxm/' + id,
    method: 'delete'
  });
};
