import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { ProjectXmglVO, ProjectXmglForm, ProjectXmglQuery } from '@/api/project/projectXmgl/types';

/**
 * 查询项目管理列表
 * @param query
 * @returns {*}
 */

export const listProjectXmgl = (query?: ProjectXmglQuery): AxiosPromise<ProjectXmglVO[]> => {
  return request({
    url: '/project/projectXmgl/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询项目管理详细
 * @param id
 */
export const getProjectXmgl = (id: string | number): AxiosPromise<ProjectXmglVO> => {
  return request({
    url: '/project/projectXmgl/' + id,
    method: 'get'
  });
};

/**
 * 新增项目管理
 * @param data
 */
export const addProjectXmgl = (data: ProjectXmglForm) => {
  return request({
    url: '/project/projectXmgl',
    method: 'post',
    data: data
  });
};

/**
 * 修改项目管理
 * @param data
 */
export const updateProjectXmgl = (data: ProjectXmglForm) => {
  return request({
    url: '/project/projectXmgl',
    method: 'put',
    data: data
  });
};

/**
 * 删除项目管理
 * @param id
 */
export const delProjectXmgl = (id: string | number | Array<string | number>) => {
  return request({
    url: '/project/projectXmgl/' + id,
    method: 'delete'
  });
};
