import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { ProjectZbdlVO, ProjectZbdlForm, ProjectZbdlQuery } from '@/api/project/projectZbdl/types';

/**
 * 查询招标代理列表
 * @param query
 * @returns {*}
 */

export const listProjectZbdl = (query?: ProjectZbdlQuery): AxiosPromise<ProjectZbdlVO[]> => {
  return request({
    url: '/project/projectZbdl/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询招标代理详细
 * @param id
 */
export const getProjectZbdl = (id: string | number): AxiosPromise<ProjectZbdlVO> => {
  return request({
    url: '/project/projectZbdl/' + id,
    method: 'get'
  });
};

/**
 * 新增招标代理
 * @param data
 */
export const addProjectZbdl = (data: ProjectZbdlForm) => {
  return request({
    url: '/project/projectZbdl',
    method: 'post',
    data: data
  });
};

/**
 * 修改招标代理
 * @param data
 */
export const updateProjectZbdl = (data: ProjectZbdlForm) => {
  return request({
    url: '/project/projectZbdl',
    method: 'put',
    data: data
  });
};

/**
 * 删除招标代理
 * @param id
 */
export const delProjectZbdl = (id: string | number | Array<string | number>) => {
  return request({
    url: '/project/projectZbdl/' + id,
    method: 'delete'
  });
};
