import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { ProjectZjzxVO, ProjectZjzxForm, ProjectZjzxQuery } from '@/api/project/projectZjzx/types';

/**
 * 查询造价咨询列表
 * @param query
 * @returns {*}
 */

export const listProjectZjzx = (query?: ProjectZjzxQuery): AxiosPromise<ProjectZjzxVO[]> => {
  return request({
    url: '/project/projectZjzx/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询造价咨询详细
 * @param id
 */
export const getProjectZjzx = (id: string | number): AxiosPromise<ProjectZjzxVO> => {
  return request({
    url: '/project/projectZjzx/' + id,
    method: 'get'
  });
};

/**
 * 新增造价咨询
 * @param data
 */
export const addProjectZjzx = (data: ProjectZjzxForm) => {
  return request({
    url: '/project/projectZjzx',
    method: 'post',
    data: data
  });
};

/**
 * 修改造价咨询
 * @param data
 */
export const updateProjectZjzx = (data: ProjectZjzxForm) => {
  return request({
    url: '/project/projectZjzx',
    method: 'put',
    data: data
  });
};

/**
 * 删除造价咨询
 * @param id
 */
export const delProjectZjzx = (id: string | number | Array<string | number>) => {
  return request({
    url: '/project/projectZjzx/' + id,
    method: 'delete'
  });
};
